@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     ActivityTypeType,
@@ -214,7 +214,7 @@ _RequiredAddResourcePermissionsRequestRequestTypeDef = TypedDict(
     "_RequiredAddResourcePermissionsRequestRequestTypeDef",
     {
         "ResourceId": str,
-        "Principals": List["SharePrincipalTypeDef"],
+        "Principals": Sequence["SharePrincipalTypeDef"],
     },
 )
 _OptionalAddResourcePermissionsRequestRequestTypeDef = TypedDict(
@@ -319,7 +319,7 @@ _RequiredCreateCustomMetadataRequestRequestTypeDef = TypedDict(
     "_RequiredCreateCustomMetadataRequestRequestTypeDef",
     {
         "ResourceId": str,
-        "CustomMetadata": Dict[str, str],
+        "CustomMetadata": Mapping[str, str],
     },
 )
 _OptionalCreateCustomMetadataRequestRequestTypeDef = TypedDict(
@@ -373,7 +373,7 @@ _RequiredCreateLabelsRequestRequestTypeDef = TypedDict(
     "_RequiredCreateLabelsRequestRequestTypeDef",
     {
         "ResourceId": str,
-        "Labels": List[str],
+        "Labels": Sequence[str],
     },
 )
 _OptionalCreateLabelsRequestRequestTypeDef = TypedDict(
@@ -500,7 +500,7 @@ _OptionalDeleteCustomMetadataRequestRequestTypeDef = TypedDict(
     {
         "AuthenticationToken": str,
         "VersionId": str,
-        "Keys": List[str],
+        "Keys": Sequence[str],
         "DeleteAll": bool,
     },
     total=False,
@@ -588,7 +588,7 @@ _OptionalDeleteLabelsRequestRequestTypeDef = TypedDict(
     "_OptionalDeleteLabelsRequestRequestTypeDef",
     {
         "AuthenticationToken": str,
-        "Labels": List[str],
+        "Labels": Sequence[str],
         "DeleteAll": bool,
     },
     total=False,
